@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 import functools
 from django.contrib.auth.models import Permission
 from django.contrib.contenttypes.models import ContentType
@@ -9,6 +10,7 @@ from pybb.subscription import notify_topic_subscribers
 from django.db import models, transaction
 from django.core.urlresolvers import reverse
 from django.db.utils import IntegrityError
+from django.utils.encoding import python_2_unicode_compatible
 from django.utils.html import strip_tags
 from django.utils.translation import ugettext_lazy as _
 from django.utils.timezone import now as tznow
@@ -52,7 +54,7 @@ class Category(models.Model):
         verbose_name = _('Category')
         verbose_name_plural = _('Categories')
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
     def forum_count(self):
@@ -70,6 +72,7 @@ class Category(models.Model):
         return Post.objects.filter(topic__forum__category=self).select_related()
 
 
+@python_2_unicode_compatible
 class Forum(models.Model):
     category = models.ForeignKey(Category, related_name='forums', verbose_name=_('Category'))
     parent = models.ForeignKey('self', related_name='child_forums', verbose_name=_('Parent forum'),
@@ -90,7 +93,7 @@ class Forum(models.Model):
         verbose_name = _('Forum')
         verbose_name_plural = _('Forums')
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
     def update_counters(self):
@@ -131,6 +134,7 @@ class Forum(models.Model):
         return parents
 
 
+@python_2_unicode_compatible
 class Topic(models.Model):
     POLL_TYPE_NONE = 0
     POLL_TYPE_SINGLE = 1
@@ -163,7 +167,7 @@ class Topic(models.Model):
         verbose_name = _('Topic')
         verbose_name_plural = _('Topics')
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
     @property
@@ -248,6 +252,7 @@ class RenderableItem(models.Model):
         self.body_text = unescape(text)
 
 
+@python_2_unicode_compatible
 class Post(RenderableItem):
     topic = models.ForeignKey(Topic, related_name='posts', verbose_name=_('Topic'))
     user = models.ForeignKey(User, related_name='posts', verbose_name=_('User'))
@@ -266,7 +271,8 @@ class Post(RenderableItem):
         tail = len(self.body) > LIMIT and '...' or ''
         return self.body[:LIMIT] + tail
 
-    __unicode__ = summary
+    def __str__(self):
+        return self.summary()
 
     def save(self, *args, **kwargs):
         created_at = tznow()
@@ -429,6 +435,7 @@ class ForumReadTracker(models.Model):
         unique_together = ('user', 'forum')
 
 
+@python_2_unicode_compatible
 class PollAnswer(models.Model):
     topic = models.ForeignKey(Topic, related_name='poll_answers', verbose_name=_('Topic'))
     text = models.CharField(max_length=255, verbose_name=_('Text'))
@@ -437,7 +444,7 @@ class PollAnswer(models.Model):
         verbose_name = _('Poll answer')
         verbose_name_plural = _('Polls answers')
 
-    def __unicode__(self):
+    def __str__(self):
         return self.text
 
     def votes(self):
@@ -451,6 +458,7 @@ class PollAnswer(models.Model):
             return 0
 
 
+@python_2_unicode_compatible
 class PollAnswerUser(models.Model):
     poll_answer = models.ForeignKey(PollAnswer, related_name='users', verbose_name=_('Poll answer'))
     user = models.ForeignKey(User, related_name='poll_answers', verbose_name=_('User'))
@@ -461,8 +469,8 @@ class PollAnswerUser(models.Model):
         verbose_name_plural = _('Polls answers users')
         unique_together = (('poll_answer', 'user', ), )
 
-    def __unicode__(self):
-        return u'%s - %s' % (self.poll_answer.topic, self.user)
+    def __str__(self):
+        return '%s - %s' % (self.poll_answer.topic, self.user)
 
 
 def post_saved(instance, **kwargs):
@@ -489,7 +497,7 @@ def user_saved(instance, created, **kwargs):
     try:
         add_post_permission = Permission.objects.get_by_natural_key('add_post', 'pybb', 'post')
         add_topic_permission = Permission.objects.get_by_natural_key('add_topic', 'pybb', 'topic')
-    except Permission.DoesNotExist, ContentType.DoesNotExist:
+    except (Permission.DoesNotExist, ContentType.DoesNotExist):
         return
     instance.user_permissions.add(add_post_permission, add_topic_permission)
     instance.save()
@@ -500,4 +508,4 @@ def user_saved(instance, created, **kwargs):
 post_save.connect(post_saved, sender=Post)
 post_delete.connect(post_deleted, sender=Post)
 if defaults.PYBB_AUTO_USER_PERMISSIONS:
-    post_save.connect(user_saved, sender=get_user_model())
\ No newline at end of file
+    post_save.connect(user_saved, sender=get_user_model())
